Index: /trunk/src/VBox/Main/src-client/ConsoleImpl2.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/ConsoleImpl2.cpp	(revision 75351)
+++ /trunk/src/VBox/Main/src-client/ConsoleImpl2.cpp	(revision 75352)
@@ -2998,5 +2998,5 @@
                 InsertConfigString(pLunL0, "Driver", "AUDIO");
             AudioDriverCfg DrvCfgVideoRec(strAudioDevice, 0 /* Instance */, uAudioLUN, "AudioVideoRec");
-            rc = Capture.mAudioVideoRec->InitializeConfig(&DrvCfgVideoRec);
+            rc = Recording.mAudioRec->InitializeConfig(&DrvCfgVideoRec);
             if (RT_SUCCESS(rc))
                 uAudioLUN++;
Index: /trunk/src/VBox/Main/src-client/DrvAudioRec.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/DrvAudioRec.cpp	(revision 75351)
+++ /trunk/src/VBox/Main/src-client/DrvAudioRec.cpp	(revision 75352)
@@ -828,5 +828,5 @@
                 case AVRECCONTAINERTYPE_MAIN_CONSOLE:
                 {
-                    HRESULT hr = pSink->Con.Main.pConsole->i_videoRecSendAudio(pStreamAV->pvDstBuf, cbDst, uPTSMs);
+                    HRESULT hr = pSink->Con.Main.pConsole->i_recordingSendAudio(pStreamAV->pvDstBuf, cbDst, uPTSMs);
                     Assert(hr == S_OK);
                     RT_NOREF(hr);
@@ -1101,5 +1101,5 @@
 int AudioVideoRec::configureDriver(PCFGMNODE pLunCfg)
 {
-    int rc = CFGMR3InsertInteger(pLunCfg, "Object",    (uintptr_t)mpConsole->i_videoRecGetAudioDrv());
+    int rc = CFGMR3InsertInteger(pLunCfg, "Object",    (uintptr_t)mpConsole->i_recordingGetAudioDrv());
     AssertRCReturn(rc, rc);
     rc = CFGMR3InsertInteger(pLunCfg, "ObjectConsole", (uintptr_t)mpConsole);

Index: /trunk/src/VBox/Main/include/ConsoleImpl.h
===================================================================
--- /trunk/src/VBox/Main/include/ConsoleImpl.h	(revision 75351)
+++ /trunk/src/VBox/Main/include/ConsoleImpl.h	(revision 75352)
@@ -141,14 +141,14 @@
     AudioVRDE *i_getAudioVRDE() const { return mAudioVRDE; }
 #endif
-#ifdef VBOX_WITH_AUDIO_RECORDING
-    int i_videoRecCreate(void);
-    void i_videoRecDestroy(void);
-    int i_videoRecEnable(BOOL fEnable, util::AutoWriteLock *pAutoLock);
-    int i_videoRecGetSettings(settings::RecordSettings &Settings);
-    int i_videoRecStart(void);
-    int i_videoRecStop(void);
-    AudioVideoRec *i_videoRecGetAudioDrv(void) const { return Capture.mAudioVideoRec; }
-    CaptureContext *i_videoRecGetContext(void) const { return Capture.mpVideoRecCtx; }
-    HRESULT i_videoRecSendAudio(const void *pvData, size_t cbData, uint64_t uDurationMs);
+#ifdef VBOX_WITH_RECORDING
+    int i_recordingCreate(void);
+    void i_recordingDestroy(void);
+    int i_recordingEnable(BOOL fEnable, util::AutoWriteLock *pAutoLock);
+    int i_recordingGetSettings(settings::RecordSettings &Settings);
+    int i_recordingStart(void);
+    int i_recordingStop(void);
+    AudioVideoRec *i_recordingGetAudioDrv(void) const { return Recording.mAudioRec; }
+    CaptureContext *i_recordingGetContext(void) const { return Recording.mpRecordCtx; }
+    HRESULT i_recordingSendAudio(const void *pvData, size_t cbData, uint64_t uDurationMs);
 #endif
 
@@ -1031,17 +1031,17 @@
 
 #ifdef VBOX_WITH_RECORDING
-    struct Capture
+    struct Recording
     {
-        Capture()
-            : mpVideoRecCtx(NULL)
-            , mAudioVideoRec(NULL) { }
-
-        /** The capturing context. */
-        CaptureContext       *mpVideoRecCtx;
+        Recording()
+            : mpRecordCtx(NULL)
+            , mAudioRec(NULL) { }
+
+        /** The recording context. */
+        CaptureContext       *mpRecordCtx;
 # ifdef VBOX_WITH_AUDIO_RECORDING
         /** Pointer to capturing audio backend. */
-        AudioVideoRec * const mAudioVideoRec;
+        AudioVideoRec * const mAudioRec;
 # endif
-    } Capture;
+    } Recording;
 #endif /* VBOX_WITH_RECORDING */
 
Index: /trunk/src/VBox/Main/include/DisplayImpl.h
===================================================================
--- /trunk/src/VBox/Main/include/DisplayImpl.h	(revision 75351)
+++ /trunk/src/VBox/Main/include/DisplayImpl.h	(revision 75352)
@@ -101,5 +101,5 @@
     {
         ComPtr<IDisplaySourceBitmap> pSourceBitmap;
-    } videoRec;
+    } Recording;
 #endif /* VBOX_WITH_RECORDING */
 } DISPLAYFBINFO;
@@ -201,6 +201,6 @@
 
 #ifdef VBOX_WITH_RECORDING
-    int  i_videoRecInvalidate(void);
-    void i_videoRecScreenChanged(unsigned uScreenId);
+    int  i_recordingInvalidate(void);
+    void i_recordingScreenChanged(unsigned uScreenId);
 #endif
 
@@ -472,6 +472,6 @@
     /* Serializes access to video recording source bitmaps. */
     RTCRITSECT           mVideoRecLock;
-    /** Array which defines which screens are being enabled for capturing. */
-    bool                 maVideoRecEnabled[SchemaDefs::MaxGuestMonitors];
+    /** Array which defines which screens are being enabled for recording. */
+    bool                 maRecordingEnabled[SchemaDefs::MaxGuestMonitors];
 #endif
 
Index: /trunk/src/VBox/Main/src-client/ConsoleImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/ConsoleImpl.cpp	(revision 75351)
+++ /trunk/src/VBox/Main/src-client/ConsoleImpl.cpp	(revision 75352)
@@ -587,6 +587,6 @@
 #endif
 #ifdef VBOX_WITH_AUDIO_RECORDING
-        unconst(Capture.mAudioVideoRec) = new AudioVideoRec(this);
-        AssertReturn(Capture.mAudioVideoRec, E_FAIL);
+        unconst(Recording.mAudioRec) = new AudioVideoRec(this);
+        AssertReturn(Recording.mAudioRec, E_FAIL);
 #endif
         FirmwareType_T enmFirmwareType;
@@ -735,8 +735,8 @@
 
 #ifdef VBOX_WITH_AUDIO_RECORDING
-    if (Capture.mAudioVideoRec)
-    {
-        delete Capture.mAudioVideoRec;
-        unconst(Capture.mAudioVideoRec) = NULL;
+    if (Recording.mAudioRec)
+    {
+        delete Recording.mAudioRec;
+        unconst(Recording.mAudioRec) = NULL;
     }
 #endif
@@ -5601,11 +5601,11 @@
 #ifdef VBOX_WITH_RECORDING
 /**
  * Enables or disables video (audio) capturing of a VM.
  *
  * @returns IPRT status code. Will return VERR_NO_CHANGE if the capturing state has not been changed.
  * @param   fEnable             Whether to enable or disable the capturing.
  * @param   pAutoLock           Pointer to auto write lock to use for attaching/detaching required driver(s) at runtime.
  */
-int Console::i_videoRecEnable(BOOL fEnable, util::AutoWriteLock *pAutoLock)
+int Console::i_recordingEnable(BOOL fEnable, util::AutoWriteLock *pAutoLock)
 {
     AssertPtrReturn(pAutoLock, VERR_INVALID_POINTER);
@@ -5616,6 +5616,6 @@
     if (pDisplay)
     {
-        const bool fIsEnabled =    Capture.mpVideoRecCtx
-                                && Capture.mpVideoRecCtx->IsStarted();
+        const bool fIsEnabled =    Recording.mpRecordCtx
+                                && Recording.mpRecordCtx->IsStarted();
 
         if (RT_BOOL(fEnable) != fIsEnabled)
@@ -5623,25 +5623,25 @@
             LogRel(("Recording: %s\n", fEnable ? "Enabling" : "Disabling"));
 
-            pDisplay->i_videoRecInvalidate();
+            pDisplay->i_recordingInvalidate();
 
             if (fEnable)
             {
-                vrc = i_videoRecCreate();
+                vrc = i_recordingCreate();
                 if (RT_SUCCESS(vrc))
                 {
 # ifdef VBOX_WITH_AUDIO_RECORDING
                     /* Attach the video recording audio driver if required. */
-                    if (   Capture.mpVideoRecCtx->IsFeatureEnabled(RecordFeature_Audio)
-                        && Capture.mAudioVideoRec)
+                    if (   Recording.mpRecordCtx->IsFeatureEnabled(RecordFeature_Audio)
+                        && Recording.mAudioRec)
                     {
-                        vrc = Capture.mAudioVideoRec->applyConfiguration(Capture.mpVideoRecCtx->GetConfig());
+                        vrc = Recording.mAudioRec->applyConfiguration(Recording.mpRecordCtx->GetConfig());
                         if (RT_SUCCESS(vrc))
-                            vrc = Capture.mAudioVideoRec->doAttachDriverViaEmt(mpUVM, pAutoLock);
+                            vrc = Recording.mAudioRec->doAttachDriverViaEmt(mpUVM, pAutoLock);
                     }
 # endif
                     if (   RT_SUCCESS(vrc)
-                        && Capture.mpVideoRecCtx->IsReady()) /* Any video recording (audio and/or video) feature enabled? */
+                        && Recording.mpRecordCtx->IsReady()) /* Any video recording (audio and/or video) feature enabled? */
                     {
-                        vrc = i_videoRecStart();
+                        vrc = i_recordingStart();
                     }
                 }
@@ -5649,9 +5649,9 @@
             else
             {
-                i_videoRecStop();
+                i_recordingStop();
 # ifdef VBOX_WITH_AUDIO_RECORDING
-                Capture.mAudioVideoRec->doDetachDriverViaEmt(mpUVM, pAutoLock);
+                Recording.mAudioRec->doDetachDriverViaEmt(mpUVM, pAutoLock);
 # endif
-                i_videoRecDestroy();
+                i_recordingDestroy();
             }
 
@@ -5676,5 +5676,5 @@
     HRESULT rc = S_OK;
 #ifdef VBOX_WITH_RECORDING
     /* Don't trigger video capture changes if the VM isn't running. */
     SafeVMPtrQuiet ptrVM(this);
     if (ptrVM.isOk())
@@ -5688,5 +5688,5 @@
         AssertComRCReturnRC(rc);
 
-        int vrc = i_videoRecEnable(fEnabled, &alock);
+        int vrc = i_recordingEnable(fEnabled, &alock);
         if (RT_SUCCESS(vrc))
         {
@@ -6876,13 +6876,13 @@
  * @param   uTimestampMs        Timestamp (in ms) of audio data.
  */
-HRESULT Console::i_videoRecSendAudio(const void *pvData, size_t cbData, uint64_t uTimestampMs)
-{
-    if (!Capture.mpVideoRecCtx)
+HRESULT Console::i_recordingSendAudio(const void *pvData, size_t cbData, uint64_t uTimestampMs)
+{
+    if (!Recording.mpRecordCtx)
         return S_OK;
 
-    if (   Capture.mpVideoRecCtx->IsStarted()
-        && Capture.mpVideoRecCtx->IsFeatureEnabled(RecordFeature_Audio))
-    {
-        return Capture.mpVideoRecCtx->SendAudioFrame(pvData, cbData, uTimestampMs);
+    if (   Recording.mpRecordCtx->IsStarted()
+        && Recording.mpRecordCtx->IsFeatureEnabled(RecordFeature_Audio))
+    {
+        return Recording.mpRecordCtx->SendAudioFrame(pvData, cbData, uTimestampMs);
     }
 
@@ -6892,5 +6892,5 @@
 
 #ifdef VBOX_WITH_RECORDING
-int Console::i_videoRecGetSettings(settings::RecordSettings &Settings)
+int Console::i_recordingGetSettings(settings::RecordSettings &Settings)
 {
     Assert(mMachine.isNotNull());
@@ -6952,7 +6952,7 @@
  * @returns IPRT status code.
  */
-int Console::i_videoRecCreate(void)
-{
-    AssertReturn(Capture.mpVideoRecCtx == NULL, VERR_WRONG_ORDER);
+int Console::i_recordingCreate(void)
+{
+    AssertReturn(Recording.mpRecordCtx == NULL, VERR_WRONG_ORDER);
 
     int rc = VINF_SUCCESS;
@@ -6960,5 +6960,5 @@
     try
     {
-        Capture.mpVideoRecCtx = new CaptureContext(this);
+        Recording.mpRecordCtx = new CaptureContext(this);
     }
     catch (std::bad_alloc &)
@@ -6972,9 +6972,9 @@
 
     settings::RecordSettings Settings;
-    rc = i_videoRecGetSettings(Settings);
+    rc = i_recordingGetSettings(Settings);
     if (RT_SUCCESS(rc))
     {
-        AssertPtr(Capture.mpVideoRecCtx);
-        rc = Capture.mpVideoRecCtx->Create(Settings);
+        AssertPtr(Recording.mpRecordCtx);
+        rc = Recording.mpRecordCtx->Create(Settings);
     }
 
@@ -6986,10 +6986,10 @@
  * Destroys the recording context.
  */
-void Console::i_videoRecDestroy(void)
-{
-    if (Capture.mpVideoRecCtx)
-    {
-        delete Capture.mpVideoRecCtx;
-        Capture.mpVideoRecCtx = NULL;
+void Console::i_recordingDestroy(void)
+{
+    if (Recording.mpRecordCtx)
+    {
+        delete Recording.mpRecordCtx;
+        Recording.mpRecordCtx = NULL;
     }
 
@@ -7002,18 +7002,18 @@
  * @returns IPRT status code.
  */
-int Console::i_videoRecStart(void)
-{
-    AssertPtrReturn(Capture.mpVideoRecCtx, VERR_WRONG_ORDER);
-
-    if (Capture.mpVideoRecCtx->IsStarted())
+int Console::i_recordingStart(void)
+{
+    AssertPtrReturn(Recording.mpRecordCtx, VERR_WRONG_ORDER);
+
+    if (Recording.mpRecordCtx->IsStarted())
         return VINF_SUCCESS;
 
     LogRel(("Recording: Starting ...\n"));
 
-    int rc = Capture.mpVideoRecCtx->Start();
+    int rc = Recording.mpRecordCtx->Start();
     if (RT_SUCCESS(rc))
     {
-        for (unsigned uScreen = 0; uScreen < Capture.mpVideoRecCtx->GetStreamCount(); uScreen++)
-            mDisplay->i_videoRecScreenChanged(uScreen);
+        for (unsigned uScreen = 0; uScreen < Recording.mpRecordCtx->GetStreamCount(); uScreen++)
+            mDisplay->i_recordingScreenChanged(uScreen);
     }
 
@@ -7028,18 +7028,18 @@
  * Stops capturing. Does nothing if capturing is not active.
  */
-int Console::i_videoRecStop(void)
-{
-    if (   !Capture.mpVideoRecCtx
-        || !Capture.mpVideoRecCtx->IsStarted())
+int Console::i_recordingStop(void)
+{
+    if (   !Recording.mpRecordCtx
+        || !Recording.mpRecordCtx->IsStarted())
         return VINF_SUCCESS;
 
     LogRel(("Recording: Stopping ...\n"));
 
-    int rc = Capture.mpVideoRecCtx->Stop();
+    int rc = Recording.mpRecordCtx->Stop();
     if (RT_SUCCESS(rc))
     {
-        const size_t cStreams = Capture.mpVideoRecCtx->GetStreamCount();
+        const size_t cStreams = Recording.mpRecordCtx->GetStreamCount();
         for (unsigned uScreen = 0; uScreen < cStreams; ++uScreen)
-            mDisplay->i_videoRecScreenChanged(uScreen);
+            mDisplay->i_recordingScreenChanged(uScreen);
 
         ComPtr<IRecordSettings> pRecordSettings;
@@ -10156,5 +10156,5 @@
         if (fCaptureEnabled)
         {
-            int vrc2 = pConsole->i_videoRecEnable(fCaptureEnabled, &alock);
+            int vrc2 = pConsole->i_recordingEnable(fCaptureEnabled, &alock);
             if (RT_SUCCESS(vrc2))
             {
@@ -5601,11 +5601,11 @@
 #ifdef VBOX_WITH_RECORDING
 /**
- * Enables or disables video (audio) capturing of a VM.
- *
- * @returns IPRT status code. Will return VERR_NO_CHANGE if the capturing state has not been changed.
- * @param   fEnable             Whether to enable or disable the capturing.
+ * Enables or disables recording of a VM.
+ *
+ * @returns IPRT status code. Will return VERR_NO_CHANGE if the recording state has not been changed.
+ * @param   fEnable             Whether to enable or disable the recording.
  * @param   pAutoLock           Pointer to auto write lock to use for attaching/detaching required driver(s) at runtime.
  */
@@ -5676,5 +5676,5 @@
     HRESULT rc = S_OK;
 #ifdef VBOX_WITH_RECORDING
-    /* Don't trigger video capture changes if the VM isn't running. */
+    /* Don't trigger recording changes if the VM isn't running. */
     SafeVMPtrQuiet ptrVM(this);
     if (ptrVM.isOk())
Index: /trunk/src/VBox/Main/src-client/DisplayImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/DisplayImpl.cpp	(revision 75351)
+++ /trunk/src/VBox/Main/src-client/DisplayImpl.cpp	(revision 75352)
@@ -150,6 +150,6 @@
     AssertRC(rc);
 
-    for (unsigned i = 0; i < RT_ELEMENTS(maVideoRecEnabled); i++)
-        maVideoRecEnabled[i] = true;
+    for (unsigned i = 0; i < RT_ELEMENTS(maRecordingEnabled); i++)
+        maRecordingEnabled[i] = true;
 #endif
 
@@ -730,5 +730,5 @@
         maFramebuffers[uScreenId].pFramebuffer.setNull();
 #ifdef VBOX_WITH_RECORDING
-        maFramebuffers[uScreenId].videoRec.pSourceBitmap.setNull();
+        maFramebuffers[uScreenId].Recording.pSourceBitmap.setNull();
 #endif
     }
@@ -1058,5 +1058,5 @@
 
 #ifdef VBOX_WITH_RECORDING
-    i_videoRecScreenChanged(uScreenId);
+    i_recordingScreenChanged(uScreenId);
 #endif
 
@@ -2407,11 +2407,11 @@
 #ifdef VBOX_WITH_RECORDING
 /**
  * Invalidates the capturing configuration.
  *
  * @returns IPRT status code.
  */
-int Display::i_videoRecInvalidate(void)
-{
-    CaptureContext *pCtx = mParent->i_videoRecGetContext();
+int Display::i_recordingInvalidate(void)
+{
+    CaptureContext *pCtx = mParent->i_recordingGetContext();
     if (!pCtx || !pCtx->IsStarted())
         return VINF_SUCCESS;
@@ -2422,13 +2422,13 @@
     for (unsigned uScreen = 0; uScreen < mcMonitors; uScreen++)
     {
-        CaptureStream *pCaptureStream = pCtx->GetStream(uScreen);
-
-        const bool fStreamEnabled = pCaptureStream->IsReady();
-              bool fChanged       = maVideoRecEnabled[uScreen] != fStreamEnabled;
-
-        maVideoRecEnabled[uScreen] = fStreamEnabled;
+        CaptureStream *pRecordingStream = pCtx->GetStream(uScreen);
+
+        const bool fStreamEnabled = pRecordingStream->IsReady();
+              bool fChanged       = maRecordingEnabled[uScreen] != fStreamEnabled;
+
+        maRecordingEnabled[uScreen] = fStreamEnabled;
 
         if (fChanged && uScreen < mcMonitors)
-            i_videoRecScreenChanged(uScreen);
+            i_recordingScreenChanged(uScreen);
     }
 
@@ -2436,9 +2436,9 @@
 }
 
-void Display::i_videoRecScreenChanged(unsigned uScreenId)
-{
-    CaptureContext *pCtx = mParent->i_videoRecGetContext();
-
-    if (   RT_LIKELY(!maVideoRecEnabled[uScreenId])
+void Display::i_recordingScreenChanged(unsigned uScreenId)
+{
+    CaptureContext *pCtx = mParent->i_recordingGetContext();
+
+    if (   RT_LIKELY(!maRecordingEnabled[uScreenId])
         || !pCtx || !pCtx->IsStarted())
     {
@@ -2454,5 +2454,5 @@
     if (RT_SUCCESS(rc2))
     {
-        maFramebuffers[uScreenId].videoRec.pSourceBitmap = pSourceBitmap;
+        maFramebuffers[uScreenId].Recording.pSourceBitmap = pSourceBitmap;
 
         rc2 = RTCritSectLeave(&mVideoRecLock);
@@ -3389,5 +3389,5 @@
 #ifdef VBOX_WITH_RECORDING
     AssertPtr(pDisplay->mParent);
-    CaptureContext *pCtx = pDisplay->mParent->i_videoRecGetContext();
+    CaptureContext *pCtx = pDisplay->mParent->i_recordingGetContext();
 
     if (   pCtx
@@ -3434,10 +3434,10 @@
             for (uScreenId = 0; uScreenId < pDisplay->mcMonitors; uScreenId++)
             {
-                if (!pDisplay->maVideoRecEnabled[uScreenId])
+                if (!pDisplay->maRecordingEnabled[uScreenId])
                     continue;
 
                 if (pCtx->IsLimitReached(uScreenId, tsNowMs))
                 {
-                    pDisplay->mParent->i_videoRecStop();
+                    pDisplay->mParent->i_recordingStop();
                     break;
                 }
@@ -3450,5 +3450,5 @@
                     if (RT_SUCCESS(rc2))
                     {
-                        pSourceBitmap = pFBInfo->videoRec.pSourceBitmap;
+                        pSourceBitmap = pFBInfo->Recording.pSourceBitmap;
                         RTCritSectLeave(&pDisplay->mVideoRecLock);
                     }
@@ -3833,5 +3833,5 @@
 {
 # ifdef VBOX_WITH_RECORDING
-    CaptureContext *pCtx = mParent->i_videoRecGetContext();
+    CaptureContext *pCtx = mParent->i_recordingGetContext();
     return (      pCtx
                && pCtx->IsReady(uScreen, uTimestampMs));
@@ -3855,5 +3855,5 @@
     Assert(mfCrOglVideoRecState == CRVREC_STATE_SUBMITTED);
 # ifdef VBOX_WITH_RECORDING
-    CaptureContext *pCtx = mParent->i_videoRecGetContext();
+    CaptureContext *pCtx = mParent->i_recordingGetContext();
 
     if (   pCtx
@@ -4499,5 +4499,5 @@
         AutoWriteLock displayLock(pThis->pDisplay COMMA_LOCKVAL_SRC_POS);
 #ifdef VBOX_WITH_RECORDING
-        pThis->pDisplay->mParent->i_videoRecStop();
+        pThis->pDisplay->mParent->i_recordingStop();
 #endif
 #ifdef VBOX_WITH_CRHGSMI
@@ -2407,11 +2407,11 @@
 #ifdef VBOX_WITH_RECORDING
 /**
- * Invalidates the capturing configuration.
+ * Invalidates the recording configuration.
  *
  * @returns IPRT status code.